# limonata

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

Either using `pip`:

``` sh
pip install limonata
```

or `conda`:

``` sh
conda install limonata
```

## How to use

You can currently set a “nature” or a “city” palette. These are palettes
we created from pictures we took. Use the following functions to set a
palette:

``` python
from limonata import set_city_palette
set_city_palette("TuebingenClassic")
```

![](nbs/index_files/figure-commonmark/cell-2-output-1.png)

Or you can see which palettes are available with the following
functions:

``` python
from limonata import show_nature_palettes
show_nature_palettes()
```

![](nbs/index_files/figure-commonmark/cell-3-output-1.png)

![](nbs/index_files/figure-commonmark/cell-3-output-2.png)

![](nbs/index_files/figure-commonmark/cell-3-output-3.png)

![](nbs/index_files/figure-commonmark/cell-3-output-4.png)

![](nbs/index_files/figure-commonmark/cell-3-output-5.png)

![](nbs/index_files/figure-commonmark/cell-3-output-6.png)

![](nbs/index_files/figure-commonmark/cell-3-output-7.png)

See the documentation [here](https://sarraahr.github.io/limonata) for
more details and examples.
